##  Getting Started with the SAP LeanIX Store
The [SAP LeanIX Store![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2Fbrowse "https://store.leanix.net/browse") provides access to custom reports developed by SAP LeanIX and external providers. As an admin user, you can download custom reports to your workspace and make them available to all workspace users. To learn more, see [Downloading Reports from the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/download-reports?locale=en-US&state=PRODUCTION&version=CLOUD "Download custom reports from the SAP LeanIX Store and make them available to all workspace users.").
The SAP LeanIX Store includes free and paid reports. SAP LeanIX reserves the right to release a paid option and other asset types, such as survey templates, configurations, and snapshots, in the future.
The SAP LeanIX Store is designed to:
  * Further grow the SAP LeanIX ecosystem by driving continuous product innovation in addition to the core product
  * Provide partners with a platform to share their knowledge and offer their expertise
  * Offer customers quick access to best practice insights, such as domain or industry-specific, to generate value in no time
